@@ -29,7 +29,7 @@ import sys
 import tempfile
 
 from giscanner import message
-from giscanner.annotationparser import AnnotationParser
+from giscanner.annotationparser import GtkDocCommentBlockParser
 from giscanner.ast import Include, Namespace
 from giscanner.dumper import compile_introspection_binary
 from giscanner.gdumpparser import GDumpParser, IntrospectionBinary
@@ -46,13 +46,22 @@ from . import utils
 def process_cflags_begin(option, opt, value, parser):
     cflags = getattr(parser.values, option.dest)
     while len(parser.rargs) > 0 and parser.rargs[0] != '--cflags-end':
-        cflags.append(parser.rargs.pop(0))
+        arg = parser.rargs.pop(0)
+        if arg == "-I" and parser.rargs and parser.rargs[0] != '--cflags-end':
+            # This is a special case where there's a space between -I and the path.
+            arg += parser.rargs.pop(0)
+        cflags.append(utils.cflag_real_include_path(arg))
 
 
 def process_cflags_end(option, opt, value, parser):
     pass
 
 
+def process_cpp_includes(option, opt, value, parser):
+    cpp_includes = getattr(parser.values, option.dest)
+    cpp_includes.append(os.path.realpath(value))
+
+
 def get_preprocessor_option_group(parser):
     group = optparse.OptionGroup(parser, "Preprocessor options")
     group.add_option("", "--cflags-begin",
@@ -63,8 +72,8 @@ def get_preprocessor_option_group(parser):
                      help="End preprocessor/compiler flags",
                      action="callback", callback=process_cflags_end)
     group.add_option("-I", help="Pre-processor include file",
-                     action="append", dest="cpp_includes",
-                     default=[])
+                     dest="cpp_includes", default=[], type="string",
+                     action="callback", callback=process_cpp_includes)
     group.add_option("-D", help="Pre-processor define",
                      action="append", dest="cpp_defines",
                      default=[])
@@ -252,7 +261,7 @@ def process_packages(options, packages):
     filtered_output = list(process_options(output, options_whitelist))
     parser = _get_option_parser()
     pkg_options, unused = parser.parse_args(filtered_output)
-    options.cpp_includes.extend(pkg_options.cpp_includes)
+    options.cpp_includes.extend([os.path.realpath(f) for f in pkg_options.cpp_includes])
     options.cpp_defines.extend(pkg_options.cpp_defines)
     options.cpp_undefines.extend(pkg_options.cpp_undefines)
 
@@ -267,7 +276,7 @@ def extract_filenames(args):
                 _error('%s: no such a file or directory' % (arg, ))
             # Make absolute, because we do comparisons inside scannerparser.c
             # against the absolute path that cpp will give us
-            filenames.append(os.path.abspath(arg))
+            filenames.append(arg)
     return filenames
 
 
@@ -289,7 +298,7 @@ def extract_filelist(options):
                 _error('%s: Invalid filelist entry-no such file or directory' % (line, ))
             # Make absolute, because we do comparisons inside scannerparser.c
             # against the absolute path that cpp will give us
-            filenames.append(os.path.abspath(filename))
+            filenames.append(filename)
     return filenames
 
 
@@ -452,7 +461,8 @@ def scanner_main(args):
     namespace = create_namespace(options)
     logger = message.MessageLogger.get(namespace=namespace)
     if options.warn_all:
-        logger.enable_warnings(True)
+        logger.enable_warnings((message.WARNING, message.ERROR, message.FATAL))
+
     transformer = create_transformer(namespace, options)
 
     packages = set(options.packages)
@@ -464,8 +474,8 @@ def scanner_main(args):
 
     ss = create_source_scanner(options, args)
 
-    ap = AnnotationParser()
-    blocks = ap.parse(ss.get_comments())
+    cbp = GtkDocCommentBlockParser()
+    blocks = cbp.parse_comment_blocks(ss.get_comments())
 
     # Transform the C symbols into AST nodes
     transformer.parse(ss.get_symbols())
