@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.6.4.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison interface for Yacc-like parsers in C
    
@@ -113,7 +113,15 @@ extern int yydebug;
      VOLATILE = 322,
      WHILE = 323,
      FUNCTION_MACRO = 324,
-     OBJECT_MACRO = 325
+     OBJECT_MACRO = 325,
+     IFDEF_GI_SCANNER = 326,
+     IFNDEF_GI_SCANNER = 327,
+     IFDEF_COND = 328,
+     IFNDEF_COND = 329,
+     IF_COND = 330,
+     ELIF_COND = 331,
+     ELSE_COND = 332,
+     ENDIF_COND = 333
    };
 #endif
 /* Tokens.  */
@@ -185,14 +193,22 @@ extern int yydebug;
 #define WHILE 323
 #define FUNCTION_MACRO 324
 #define OBJECT_MACRO 325
+#define IFDEF_GI_SCANNER 326
+#define IFNDEF_GI_SCANNER 327
+#define IFDEF_COND 328
+#define IFNDEF_COND 329
+#define IF_COND 330
+#define ELIF_COND 331
+#define ELSE_COND 332
+#define ENDIF_COND 333
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-/* Line 2077 of yacc.c  */
-#line 134 "giscanner/scannerparser.y"
+/* Line 2058 of yacc.c  */
+#line 212 "giscanner/scannerparser.y"
 
   char *str;
   GList *list;
@@ -204,8 +220,8 @@ typedef union YYSTYPE
   UnaryOperator unary_operator;
 
 
-/* Line 2077 of yacc.c  */
-#line 209 "scannerparser.h"
+/* Line 2058 of yacc.c  */
+#line 225 "scannerparser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
